@@ -6,6 +6,8 @@
 {
     IBOutlet NSWindow *inspectorWindow;
 	IBOutlet NSMenuItem *affectInspectorMenu;
+	IBOutlet NSTableView *variableList;
+	IBOutlet NSTableView *historyList;
 }
 - (IBAction)closeIt:(id)sender;
 - (IBAction)openIt:(id)sender;
