@@ -7,7 +7,7 @@
  *
  */
 
-#ifndef GUI
+#ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 #include <stdio.h>
@@ -19,67 +19,67 @@
 
 /* based on Meters */
 const struct conversion lengths[] = {
-    {"10000000000",     "Angstroms",            {"Å","angstroms",NULL}},
+    {"10000000000",     "Angstroms",            {"Å","angstrom","angstroms",NULL}},
     {"6.68457808276714901267478224803e-12",
-                        "Astronomical Units",   {"AU","ua","astronomical_units",NULL}},
-    {"0.004557",        "Cable Lengths",        {"cable_lengths",NULL}},
-    {"100",             "Centimeters",          {"cm","centimeters",NULL}},
-    {"0.04971",         "Chains",               {"ch","chains",NULL}},
-    {"2.187227",        "Cubits",               {"cubits",NULL}},
-    {"0.546807",        "Fathoms",              {"fth","fath","fathoms",NULL}},
-    {"3.2808399",       "Feet",                 {"ft","feet","'",NULL}},
-    {"0.004971",        "Furlongs",             {"fur","furlongs",NULL}},
-    {"39.370079",       "Inches",               {"in","inches","\"",NULL}},
-    {"0.001",           "Kilometers",           {"km","kilometers",NULL}},
-    {"0.000207",        "Leagues",              {"leagues",NULL}},
-    {"0.00018",         "Nautical Leagues",     {"nautical_leagues",NULL}},
+                        "Astronomical Units",   {"AU","ua","astronomical_unit","astronomical_units",NULL}},
+    {"0.004557",        "Cable Lengths",        {"cable_length","cable_lengths",NULL}},
+    {"100",             "Centimeters",          {"cm","centimeter","centimeters",NULL}},
+    {"0.04971",         "Chains",               {"ch","chain","chains",NULL}},
+    {"2.187227",        "Cubits",               {"cubit","cubits",NULL}},
+    {"0.546807",        "Fathoms",              {"fth","fath","fathom","fathoms",NULL}},
+    {"3.28083991666666","Feet",                 {"ft","feet","foot","'",NULL}},
+    {"0.004971",        "Furlongs",             {"fur","furlong","furlongs",NULL}},
+    {"39.3700789999999","Inches",               {"in","inch","inches","\"",NULL}},
+    {"0.001",           "Kilometers",           {"km","kilometer","kilometers",NULL}},
+    {"0.000207",        "Leagues",              {"league","leagues",NULL}},
+    {"0.00018",         "Nautical Leagues",     {"nautical_league","nautical_leagues",NULL}},
     {"1.05702289450170391750030273856e-16",
-                        "Light-years",          {"ly","lightyears",NULL}},
-    {"4.97097",         "Links",                {"links",NULL}},
-    {"1.00",            "Meters",               {"m","meters",NULL}},
-    {"39370078.740157", "Microinches",          {"mci","microinches",NULL}},
-    {"1000000",         "Microns",              {"µ","microns",NULL}},
-    {"0.000621",        "Miles",                {"mi","miles",NULL}},
-    {"0.000539957",     "Nautical Miles",       {"nmi","n_mile","naut_mi","NM","n.m.","nautical_miles",NULL}},
-    {"1000",            "Millimeters",          {"mm","millimeters",NULL}},
-    {"39370.07874",     "Mils",                 {"mils",NULL}},
-    {"1000000000",      "Nanometers",           {"nm","nanometers",NULL}},
+                        "Light-years",          {"ly","lightyear","lightyears",NULL}},
+    {"4.97097",         "Links",                {"link","links",NULL}},
+    {"1.00",            "Meters",               {"m","meter","meters",NULL}},
+    {"39370078.740157", "Microinches",          {"mci","microinch","microinches",NULL}},
+    {"1000000",         "Microns",              {"µ","micron","microns",NULL}},
+    {"0.000621",        "Miles",                {"mi","mile","miles",NULL}},
+    {"0.000539957",     "Nautical Miles",       {"nmi","n_mile","n_miles","naut_mi","NM","n.m.","nautical_mile","nautical_miles",NULL}},
+    {"1000",            "Millimeters",          {"mm","millimeter","millimeters",NULL}},
+    {"39370.07874",     "Mils",                 {"mil","mils",NULL}},
+    {"1000000000",      "Nanometers",           {"nm","nanometer","nanometers",NULL}},
     {"3.24077648680546210191415652999e-17",
-                        "Parsec",               {"pc","psc","parsecs",NULL}},
-    {"236.2205",        "Pica",                 {"pi","picas",NULL}},
-    {"2834.6457",       "Points",               {"pt","points",NULL}},
-    {"0.198839",        "Rods",                 {"rd","rods",NULL}},
-    {"4.374453",        "Spans",                {"spans",NULL}},
-    {"1.1811",          "Varas",                {"varas",NULL}},
-    {"1.093613",        "Yards",                {"yd","yards",NULL}},
+                        "Parsec",               {"pc","psc","parsec","parsecs",NULL}},
+    {"236.2205",        "Pica",                 {"pi","pica","picas",NULL}},
+    {"2834.6457",       "Points",               {"pt","point","points",NULL}},
+    {"0.198839",        "Rods",                 {"rd","rod","rods",NULL}},
+    {"4.374453",        "Spans",                {"span","spans",NULL}},
+    {"1.1811",          "Varas",                {"vara","varas",NULL}},
+    {"1.093613",        "Yards",                {"yd","yard","yards",NULL}},
     {NULL,NULL,{NULL}}
 };
 
 /* based on Acres */
 const struct conversion areas[] = {
-    {"1.00",              "Acre",                           {"ac","A","acres",NULL}},
-    {"1.21",              "Commercial Acre",                {"commercial_acre",NULL}},
-    {"0.617369",          "Irish Acre",                     {"irish_acres",NULL}},
-    {"0.999996",          "Survey Acre",                    {"survey_acres",NULL}},
-    {"40.468564",         "Are",                            {"a",NULL}},
+    {"1.00",              "Acre",                           {"ac","A","acre","acres",NULL}},
+    {"1.21",              "Commercial Acre",                {"commercial_acre","commercial_acres",NULL}},
+    {"0.617369",          "Irish Acre",                     {"irish_acre","irish_acres",NULL}},
+    {"0.999996",          "Survey Acre",                    {"survey_acre","survey_acres",NULL}},
+    {"40.468564",         "Are",                            {"a","are","ares",NULL}},
     {"200.020406",        "Base boxe (tin plated steel)",   {"base_boxe",NULL}},
-    {"1224.0945",         "Bin (Taiwan)",                   {"bin",NULL}},
+    {"1224.0945",         "Bin (Taiwan)",                   {"bin","bins",NULL}},
     {"1224.0945",         "Bu (Japan)",                     {"bu.JP",NULL}},
     {"9.176545",          "Cantero (Ecuador)",              {"cantero",NULL}},
     {"11.241268",         "Cao (Vietnam)",                  {"cao",NULL}},
     {"0.617369",          "Colpa (Ireland)",                {"colpas","colps","collops",NULL}},
-    {"4046.8564",         "Centaire",                       {"ca","centiare",NULL}},
-    {"0.404686",          "Hectare",                        {"ha","hectares",NULL}},
+    {"4046.8564",         "Centaire",                       {"ca","centiare","cetaires",NULL}},
+    {"0.404686",          "Hectare",                        {"ha","hectare","hectares",NULL}},
     {"5.645726",          "Labor (Canada)",                 {"labors.CA",NULL}},
-    {"0.005645",          "Labor (US)",                     {"labors.US","labors",NULL}},
-    {"0.579036",          "Manzana (Costa Rica)",           {"manzanas","manzanas.CR",NULL}},
+    {"0.005645",          "Labor (US)",                     {"labors.US","labor","labors",NULL}},
+    {"0.579036",          "Manzana (Costa Rica)",           {"manzana","manzanas","manzanas.CR",NULL}},
     {"0.404686",          "Manzana (Argentina)",            {"manzanas.AR",NULL}},
     {"2.529285",          "Rai (Thailand)",                 {"rai",NULL}},
-    {"3.999984",          "Rood",                           {"roods",NULL}},
+    {"3.999984",          "Rood",                           {"rood","roods",NULL}},
     {"11.241268",         "Sao (Vietnam)",                  {"sao",NULL}},
     {"463.027064",        "Scruple (ancient Rome)",         {"scruples.Rome",NULL}},
-    {"0.001562",          "Section (US Survey)",            {"sec","sections",NULL}},
-    {"435.599981",        "Square",                         {"sq","square",NULL}},
+    {"0.001562",          "Section (US Survey)",            {"sec","section","sections",NULL}},
+    {"435.599981",        "Square",                         {"sq","square","squares",NULL}},
     {"48.401584",         "Square (Sri Lanka)",             {"sq.SL",NULL}},
     {"62726399652.54841", "Square Caliber",                 {"sq.cal.",NULL}},
     {"40468564",          "Square Centimeter",              {"sq.cm.",NULL}},
@@ -93,7 +93,7 @@ const struct conversion areas[] = {
     {"4839.980766",       "Square US Survey Yard",          {"sq.yd.","sq.yd.US",NULL}},
     {"0.001562",          "Square Miles",                   {"sq.mi.","square_miles",NULL}},
     {"38358.828494",      "Square Paris Foot (Canada)",     {"sq.ft.CA",NULL}},
-    {"0.000043",          "Township",                       {"twp","townships",NULL}},
+    {"0.000043",          "Township",                       {"twp","township","townships",NULL}},
     {NULL,NULL,{NULL}}
 };
 
@@ -101,71 +101,71 @@ const struct conversion areas[] = {
 const struct conversion volumes[] = {
     {"4",              "#2.5 can",                  {"2.5can",NULL}},
     {"1",              "#10 can",                   {"10can",NULL}},
-    {"0.031746",       "Barrel (US, liquid)",       {"bbl","barrels",NULL}},
+    {"0.031746",       "Barrel (US, liquid)",       {"bbl","barrel","barrels",NULL}},
     {"1.604167",       "Board Foot",                {"bd_ft","fbm","BF","board_feet",NULL}},
     {"0.107421",       "Bushel (US)",               {"bu",NULL}},
-    {"3071.09474",     "Coffeespoon",               {"coffeespoons",NULL}},
-    {"3784.296607",    "Cooking milliliter",        {"cooking_milliliters",NULL}},
-    {"0.001044",       "Cord (firewood)",           {"cd","cords",NULL}},
-    {"0.008355",       "Cord Foot (timber)",        {"cd_ft","cord_feet",NULL}},
-    {"3785.411784",    "Cubic Centimeter",          {"cc","cm3","cubic_centimeters",NULL}},
-    {"3.785411784",    "Cubic Decimeter",           {"dm3","cubic_decimeters",NULL}},
-    {"0.133681",       "Cubic Foot",                {"ft3","cubic_feet",NULL}},
-    {"231",            "Cubic Inch",                {"i3","cubic_inches",NULL}},
-    {"0.003785411784", "Cubic Meter",               {"m3","cubic_meters",NULL}},
-    {"16",             "Cup (US)",                  {"c","cups",NULL}},
+    {"3071.09474",     "Coffeespoon",               {"coffeespoon","coffeespoons",NULL}},
+    {"3784.296607",    "Cooking milliliter",        {"cooking_milliliter","cooking_milliliters",NULL}},
+    {"0.001044",       "Cord (firewood)",           {"cd","cord","cords",NULL}},
+    {"0.008355",       "Cord Foot (timber)",        {"cd_ft","cord_foot","cord_feet",NULL}},
+    {"3785.411784",    "Cubic Centimeter",          {"cc","cm3","cubic_centimeter","cubic_centimeters",NULL}},
+    {"3.785411784",    "Cubic Decimeter",           {"dm3","cubic_decimeter","cubic_decimeters",NULL}},
+    {"0.133681",       "Cubic Foot",                {"ft3","cubic_foot","cubic_feet",NULL}},
+    {"231",            "Cubic Inch",                {"i3","cubic_inch","cubic_inches",NULL}},
+    {"0.003785411784", "Cubic Meter",               {"m3","cubic_meter","cubic_meters",NULL}},
+    {"16",             "Cup (US)",                  {"c","cups","cup",NULL}},
     {"12284.379957",   "Dash",                      {"ds",NULL}},
-    {"58350.801541",   "Drop",                      {"gtt","drops",NULL}},
-    {"5",              "Fifth",                     {"fifths",NULL}},
+    {"58350.801541",   "Drop",                      {"gtt","drops","drop",NULL}},
+    {"5",              "Fifth",                     {"fifths","fifth",NULL}},
     {"127.999998",     "Fluid Ounce (US)",          {"fl.oz.","fl.oz.US",NULL}},
     {"133.227867",     "Fluid Ounce (UK)",          {"fl.oz.UK",NULL}},
-    {"1",              "Gallon (US)",               {"gal","gallons",NULL}},
-    {"32",             "Gill (US)",                 {"gi","gills",NULL}},
-    {"0.03785411784",  "Hectoliter",                {"hl","hectoliters",NULL}},
-    {"0.015873",       "Hogshead (US)",             {"hhd","hogsheads",NULL}},
-    {"85.333334",      "Jigger",                    {"jiggers",NULL}},
-    {"3.785411784",    "Liter",                     {"l","liters",NULL}},
-    {"0.491612",       "Measure (Ancient Hebrew)",  {"measures",NULL}},
-    {"3785.411784",    "Milliliter",                {"ml","milliliters",NULL}},
-    {"8",              "Pint (US)",                 {"pt","pints",NULL}},
-    {"0.429684",       "Peck (US)",                 {"pk","pecks",NULL}},
-    {"6142.189979",    "Pinch",                     {"pinches",NULL}},
-    {"0.007937",       "Pipe (US)",                 {"pipes",NULL}},
+    {"1",              "Gallon (US)",               {"gal","gallon","gallons",NULL}},
+    {"32",             "Gill (US)",                 {"gi","gill","gills",NULL}},
+    {"0.03785411784",  "Hectoliter",                {"hl","hectoliter","hectoliters",NULL}},
+    {"0.015873",       "Hogshead (US)",             {"hhd","hogshead","hogsheads",NULL}},
+    {"85.333334",      "Jigger",                    {"jigger","jiggers",NULL}},
+    {"3.785411784",    "Liter",                     {"l","liter","liters",NULL}},
+    {"0.491612",       "Measure (Ancient Hebrew)",  {"measure","measures",NULL}},
+    {"3785.411784",    "Milliliter",                {"ml","milliliter","milliliters",NULL}},
+    {"8",              "Pint (US)",                 {"pt","pint","pints",NULL}},
+    {"0.429684",       "Peck (US)",                 {"pk","peck","pecks",NULL}},
+    {"6142.189979",    "Pinch",                     {"pinch","pinches",NULL}},
+    {"0.007937",       "Pipe (US)",                 {"pipe","pipes",NULL}},
     {"127.999998",     "Pony",                      {"pony","ponies",NULL}},
-    {"4",              "Quart (US)",                {"qt","quarts",NULL}},
-    {"0.013011",       "Quarter (UK)",              {"qtr.UK","Q.UK","quarters.UK",NULL}},
-    {"0.003785411784", "Stere",                     {"st","steres",NULL}},
-    {"3197.46888",     "Scruple (UK)",              {"scruples.UK",NULL}},
-    {"256",            "Tablespoon (US)",           {"tbsp","tbsp.US","tablespoons",NULL}},
+    {"4",              "Quart (US)",                {"qt","quart","quarts",NULL}},
+    {"0.013011",       "Quarter (UK)",              {"qtr.UK","Q.UK","quarter.UK","quarters.UK",NULL}},
+    {"0.003785411784", "Stere",                     {"st","stere","steres",NULL}},
+    {"3197.46888",     "Scruple (UK)",              {"scruple.UK","scruples.UK",NULL}},
+    {"256",            "Tablespoon (US)",           {"tbsp","tbsp.US","tablespoon","tablespoons",NULL}},
     {"204.745415",     "Tablespoon (UK)",           {"tbsp.UK",NULL}},
-    {"768",            "Teaspoon (US)",             {"tsp","tsp.US","teaspoons",NULL}},
+    {"768",            "Teaspoon (US)",             {"tsp","tsp.US","teaspoon","teaspoons",NULL}},
     {"818.981651",     "Teaspoon (UK)",             {"tsp.UK",NULL}},
     {NULL,NULL,{NULL}}
 };
 
 /* based on the Avoirdupois Pound */
 const struct conversion masses[] = {
-    {"2268",                 "Carat",                   {"ct","carats",NULL}},
-    {"256",                  "Dram (Avoirdupois)",      {"dr.Av","dr","drams",NULL}},
+    {"2268",                 "Carat",                   {"ct","carat","carats",NULL}},
+    {"256",                  "Dram (Avoirdupois)",      {"dr.Av","dr","dram","drams",NULL}},
     {"116.666666666667",     "Dram (Apothecaries)",     {"dr.Ap",NULL}},
-    {"7000",                 "Grain",                   {"gr","grains",NULL}},
-    {"453.6",                "Gram",                    {"g","grams",NULL}},
-    {"0.0004536",            "Microgram",               {"µg","mcg","micrograms",NULL}},
-    {"0.4536",               "Milligram",               {"mg","milligrams",NULL}},
-    {"0.01",                 "Hundredweight (US)",      {"Cwt","cwt",NULL}},
-    {"0.4536",               "Kilogram",                {"kg","kilograms",NULL}},
-    {"16",                   "Ounce (Avoir.)",          {"oz","ounces","oz.Av",NULL}},
+    {"7000",                 "Grain",                   {"gr","grain","grains",NULL}},
+    {"453.6",                "Gram",                    {"g","gram","grams",NULL}},
+    {"0.0004536",            "Microgram",               {"µg","mcg","microgram","micrograms",NULL}},
+    {"0.4536",               "Milligram",               {"mg","milligram","milligrams",NULL}},
+    {"0.01",                 "Hundredweight (US)",      {"Cwt","cwt","hundredweight","hundredweights",NULL}},
+    {"0.4536",               "Kilogram",                {"kg","kilogram","kilograms",NULL}},
+    {"16",                   "Ounce (Avoir.)",          {"oz","ounce","ounces","oz.Av",NULL}},
     {"14.5833333333334",     "Ounce (Apoth. & Troy)",   {"oz.Ap","oz.Tr",NULL}},
-    {"291.666666666667",     "Pennyweight",             {"dwt","pwt","pennyweights",NULL}},
-    {"1.21527777777777",     "Pound (Troy)",            {"lb_t","lb.Tr","#","lb",NULL}},
-    {"1",                    "Pound (Avoir.)",          {"lb_av","lb.Av","lbm",NULL}},
-    {"0.04",                 "Quarter (US)",            {"qtr","Q","Qr","quarters","Qr.US",NULL}},
-    {"350",                  "Scruple (Apoth.)",        {"s","scruples","s.Ap",NULL}},
-    {"0.03105590062111801",  "Slug",                    {"slugs",NULL}},
-    {"0.07142857142857142",  "Stone",                   {"stones",NULL}},
-    {"0.0005",               "Short Ton",               {"T","tons","short_tons",NULL}},
-    {"0.0004536",            "Metric Ton / Tonne",      {"MT","t","metric_tons",NULL}},
-    {"0.0004464285714285714","Long Ton",                {"L.T.","LT","long_tons",NULL}},
+    {"291.666666666667",     "Pennyweight",             {"dwt","pwt","pennyweight","pennyweights",NULL}},
+    {"1.21527777777777",     "Pound (Troy)",            {"lb_t","lb.Tr","#",NULL}},
+    {"1",                    "Pound (Avoir.)",          {"lb","lb_av","lb.Av","lbs","pounds","pound",NULL}},
+    {"0.04",                 "Quarter (US)",            {"qtr","Q","Qr","quarter","quarters","Qr.US",NULL}},
+    {"350",                  "Scruple (Apoth.)",        {"s","scruple","scruples","s.Ap",NULL}},
+    {"0.03105590062111801",  "Slugs",                   {"slug","slugs",NULL}},
+    {"0.07142857142857142",  "Stone",                   {"stone","stones",NULL}},
+    {"0.0005",               "Short Ton",               {"T","ton","tons","short_ton","short_tons",NULL}},
+    {"0.0004536",            "Metric Ton / Tonne",      {"MT","t","metric_ton","metric_tons",NULL}},
+    {"0.0004464285714285714","Long Ton",                {"L.T.","LT","long_ton","long_tons",NULL}},
     {NULL,NULL,{NULL}}
 };
 
@@ -177,10 +177,10 @@ const struct conversion speeds[] = {
     {"60",                     "Feet/minute",                   {"f/m",NULL}},
     {"0.0909090909090909091",  "Furlongs/minute",               {"fur/m",NULL}},
     {"1.0972853161278995",     "Kilometers/hour",               {"km/h",NULL}},
-    {"0.5924837511331251",     "Knots",                         {"k","knot",NULL}},
-    {"5.454644629902362",      "Leagues/day",                   {"leagues/day",NULL}},
-    {"0.0009191187537183524",  "Mach (dry air, 273 kelvin)",    {"M","Ma","machs",NULL}},
-    {"0.68181818181818181819", "Miles/hour",                    {"mph","miles/hr","miles/hour",NULL}},
+    {"0.5924837511331251",     "Knots",                         {"k","knot","knots",NULL}},
+    {"5.454644629902362",      "Leagues/day",                   {"leagues/day","league/day",NULL}},
+    {"0.0009191187537183524",  "Mach (dry air, 273 kelvin)",    {"M","Ma","mach","machs",NULL}},
+    {"0.68181818181818181819", "Miles/hour",                    {"mph","mile/hr","miles/hr","mile/hour","miles/hour",NULL}},
     {NULL,NULL,{NULL}}
 };
 
@@ -188,44 +188,44 @@ const struct conversion speeds[] = {
 const struct conversion powers[] = {
     {"2547.160889", "BTU/hour",             {"BTU/hr",NULL}},
     {"7460000000",  "Ergs/sec",             {"ergs/s",NULL}},
-    {"550.221342",  "Foot-lbs/sec",         {"ft-lbf/s","ft-lb/s","foot-pounds_per_second",NULL}},
+    {"550.221342",  "Foot-lbs/sec",         {"ft-lbf/s","ft-lb/s","foot-pound_per_second","foot-pounds_per_second",NULL}},
     {"1",           "Horsepower",           {"hp","horse","horsepower",NULL}},
     {"10.697948",   "KiloCalories/min",     {"kC/m",NULL}},
     {"0.178299",    "KiloCalories/sec",     {"kC/s",NULL}},
-    {"0.746",       "Kilowatts",            {"kW","kilowatts",NULL}},
-    {"0.000000746", "Gigawatts",            {"GW","gigawatts",NULL}},
-    {"0.000746",    "Megawatts",            {"MW","megawatts",NULL}},
-    {"746000",      "Milliwatts (mW)",      {"mW","milliwatts",NULL}},
-    {"746",         "Watts (joules/sec)",   {"W","watts","J/s",NULL}},
+    {"0.746",       "Kilowatts",            {"kW","kilowatt","kilowatts",NULL}},
+    {"0.000000746", "Gigawatts",            {"GW","gigawatt","gigawatts",NULL}},
+    {"0.000746",    "Megawatts",            {"MW","megawatt","megawatts",NULL}},
+    {"746000",      "Milliwatts (mW)",      {"mW","milliwatt","milliwatts",NULL}},
+    {"746",         "Watts (joules/sec)",   {"W","watt","watts","J/s",NULL}},
     {NULL,NULL,{NULL}}
 };
 
 /* based on Newtons */
 const struct conversion forces[] = {
-    {"100000",     "Dyne",                  {"dyn","dynes",NULL}},
+    {"100000",     "Dyne",                  {"dyn","dyne","dynes",NULL}},
     {"101.971621", "Gram-force",            {"gf","gram-force",NULL}},
-    {"0.101972",   "Kilopond (kgm-force)",  {"kgf","kiloponds",NULL}},
-    {"0.000225",   "Kip (kilopound",        {"kips","kilopounds",NULL}},
-    {"1",          "Newton",                {"N","newton",NULL}},
-    {"0.224809",   "Pound",                 {"lbf","pound_force",NULL}},
-    {"7.233011",   "Poundal",               {"pdl","pl","poundals",NULL}},
+    {"0.101972",   "Kilopond (kgm-force)",  {"kgf","kilopond","kiloponds",NULL}},
+    {"0.000225",   "Kip (kilopound",        {"kips","kilopound","kilopounds",NULL}},
+    {"1",          "Newton",                {"N","newton","newtons",NULL}},
+    {"0.224809",   "Pound",                 {"lbf","pound_force","pounds_force",NULL}},
+    {"7.233011",   "Poundal",               {"pdl","pl","poundal","poundals",NULL}},
     {NULL,NULL,{NULL}}
 };
 
 /* based on meters per square second */
 const struct conversion accelerations[] = {
-    {"3.28084",    "Celo",                      {"celos",NULL}},
-    {"10000",      "Centigal",                  {"centigals",NULL}},
+    {"3.28084",    "Celo",                      {"celo","celos",NULL}},
+    {"10000",      "Centigal",                  {"centigal","centigals",NULL}},
     {"100",        "Centimeter/square second",  {"cm/s/s","cm/s^2",NULL}},
-    {"1000",       "Decigal",                   {"Dg","decigals",NULL}},
+    {"1000",       "Decigal",                   {"Dg","decigal","decigals",NULL}},
     {"3.28084",    "Foot/square second",        {"f/s/s","f/s^2",NULL}},
     {"0.101972",   "G-unit (G)",                {"G","G-units",NULL}},
-    {"100",        "Galileo",                   {"Gal","gal","galileos",NULL}},
-    {"0.101972",   "Grav",                      {"gravs",NULL}},
+    {"100",        "Galileo",                   {"Gal","gal","galileo","galileos",NULL}},
+    {"0.101972",   "Grav",                      {"grav","gravs",NULL}},
     {"39.370079",  "Inch/square second",        {"in/s/s","in/s^2",NULL}},
     {"3.6",        "Kilometer/hour/second",     {"km/h/s",NULL}},
     {"0.001",      "Kilometer/square second",   {"km/s/s","km/s^2",NULL}},
-    {"0.1",        "Leo",                       {"leos",NULL}},
+    {"0.1",        "Leo",                       {"leo","leos",NULL}},
     {"1",          "Meter/square second",       {"m/s/s","m/s^2",NULL}},
     {"134.216178", "Mile/hour/minute",          {"mi/h/m",NULL}},
     {"2.236936",   "Mile/hour/second",          {"mi/h/s",NULL}},
@@ -337,6 +337,8 @@ void uber_conversion (mpfr_t output, int utype, int fromunit, int tounit, mpfr_t
         mpfr_init_set_str(fromfac,ltable[fromunit].factor,0,GMP_RNDN);
         mpfr_div(tofac,tofac,fromfac,GMP_RNDN);
         mpfr_mul(output,tofac,value,GMP_RNDN);
+        mpfr_clear(tofac);
+        mpfr_clear(fromfac);
     } else {
         mpfr_t temp;
 
